;;  This file contains the definitions that the user might reasonably want to
;;    change.  This includes the I/O pin mappings, the baud rate, and some
;;    clock-related items. These files were created by Phil Short (Mr. Renard), Peter Rogers
;;    and modified to accommodate a 32 channel controller by Mac Macmillan (Mactayl)
;;
;;  The following user-configurable items are not included in this file.
;;  1) Invocation of this file (located in the file ren32_g2-03122011.asm)
;;  2) Processor selection (located as a menu item in the MPLAB IDE).
;;
;;  Hardware mappings
;;  PIN 1  (RE3) - zero-crossing (not used)
;;  PIN 2  (RA0) -  driver 1 (output)
;;  PIN 3  (RA1) -  driver 2 (output)
;;  PIN 4  (RA2) -  driver 3 (output)
;;  PIN 5  (RA3) -  driver 4 (output)
;;  PIN 6  (RA4) -  driver 5 (output)
;;  PIN 7  (RA5) -  driver 6 (output)
;;  PIN 8  (RE0) -  driver 7 (output)
;;  PIN 9  (RE1) -  driver 8 (output) 
;;  PIN 10 (RE2) -  driver 9 (output)
;;  PIN 11 (VDD) 
;;  PIN 12 (VSS) 
;;  PIN 13 (RA7) -  driver 10 (output)
;;  PIN 14 (RA6) -  driver 11 (output)
;;  PIN 15 (RC0) -  driver 12 (output)
;;  PIN 16 (RC1) -  driver 13 (output)
;;  PIN 17 (RC2) -  driver 14 (output)
;;  PIN 18 (RC3) -  driver 15 (output)
;;  Pin 19 (RD0) -  driver 16 (output)
;;  Pin 20 (RD1) - Status LED HeartBeat
;;  PIN 21 (RD2) -  driver 29 (output)
;;  PIN 22 (RD3) -  driver 30 (output)
;;  PIN 23 (RC4) -  driver 31 (output)
;;  PIN 24 (RC5) -  driver 32 (output)
;;  PIN 25 (RC6/TX) - uart_out (output)
;;  PIN 26 (RC7/RX) - uart_in (input)
;;  PIN 27 (RD4) -  driver 25 (output)
;;  PIN 28 (RD5) -  driver 26 (output)
;;  PIN 29 (RD6) -  driver 27 (output)
;;  PIN 30 (RD7) -  driver 28 (output)
;;  PIN 31 (VSS)
;;  PIN 32 (VDD)
;;  PIN 33 (RB0) -  driver 21 (output)
;;  PIN 34 (RB1) -  driver 22 (output)
;;  PIN 35 (RB2) -  driver 23 (output)
;;  PIN 36 (RB3) -  driver 24 (output)
;;  PIN 37 (RB4) -  driver 17 (output)
;;  PIN 38 (RB5) -  driver 18 (output)
;;  PIN 39 (RB6) -  driver 19 (output)
;;  PIN 40 (RB7) -  driver 20 (output)


;;  NOTE:
;;
;;  This firmware is configured for PWM use with 57600 baud communications.
;;  Here are the DEFINE statements for changing this.
;;
;;  User tunable items:
	
;; define baud rates. uncomment one of the following options
;; #define BAUDRATE 38400  ;; not tested on 32 Channels
;; #define BAUDRATE 57600
 #define BAUDRATE 115200

;; Start address for channel start configuration on controller
;; also required for Ren-W wireless operation,, max baud rate is 57600

 #DEFINE START_ADDRESS  ;; comment this line out for non start address configuration

 #DEFINE START_ADDR 24  ;; 0 starts channels 1-8, see Start Address Chart in
;;                           Wiki for more info under Ren-W section

;; CTR_LOCKOUT turns all outputs off early if it is > 0.

 #define CTR_LOCKOUT 0

;;**************** Internal OSC settings *********************

;; #define CLOCKRATE 64000000  ;;will only work with PIC18F45K22 for DC_LEDS
 #define CLOCKRATE 32000000  ;;PIC18F4xxx or PIC18F45K22


;; All PIC18F parts currently require '1<<PLLEN' here.

 #DEFINE OSC_TUNE_LOCAL 1<<PLLEN ;; {pr} fixed typo

;; I/O bit definitions

 #define ZC_BIT   3
 #define ZC_REG	  PORTE
 #define ZC       ZC_REG,(ZC_BIT)
 #define ZC_MASK  (1<<(ZC_BIT))


;;  Status LED Port D bit 3 only 

 #define HEARTBEAT_LED_REG  LED_map
 #define HEARTBEAT_LED	HEARTBEAT_LED_REG, HEARTBEAT_LED_BIT

 #define ZC_LED_BIT 0
 #define ZC_LED_REG LED_map
 #define ZC_LED ZC_LED_REG,ZC_LED_BIT
	
 #define FRAME_ERR_LED_REG  LED_map
 #define FRAME_ERR_LED  FRAME_ERR_LED_REG, FRAME_ERR_LED_BIT
	
 #define RXD_LED_REG LED_map
 #define RXD_LED RXD_LED_REG, RXD_LED_BIT


;;  --------------------------------------------------------------------------
;;  Macros for assigning dimmer input channels to IO pins.
;;
;;  The serial communicationss and zero-crossing pins are pre-assigned, and are
;;    not intended to be easily changed.
;;
;;  This is also where output polarity and PWM vs non-PWM status is assigned.
;;  If the SINK_PORTx_CHy bit is set to '1' the signal will be active low, if
;;    it is set '0' the output signal will be active high.  Similarly, if the
;;    PORTx_CHy bit is set to '1' the output will be a PWM signal, if set
;;    to '0' the output will be just a pulse (although this latter option only
;;    makes sense when driving a TRIAC or SCR).

;;  Note: the pins used for LED output must have the SINK bit in the 'OFF'
;;    state and the PWM pin in the 'ON' state.

#IFNDEF YES
  #DEFINE YES 1
#ENDIF
#IFNDEF NO
  #DEFINE NO 0
#ENDIF


;;*************** This code is setup for 8 Ports of RGB+W Only ****************** 
	
;;  PortA, bit 0 has channel 1 mapped to it
  #DEFINE PIN2_CH 1
  #DEFINE PIN2_SINK NO
  #DEFINE PIN2_PWM YES
	
;;  PortA, bit 1 has channel 2 mapped to it
  #DEFINE PIN3_CH 2
  #DEFINE PIN3_SINK NO
  #DEFINE PIN3_PWM YES
	
;;  PortA, bit 2 has channel 3 mapped to it
  #DEFINE PIN4_CH 3
  #DEFINE PIN4_SINK NO
  #DEFINE PIN4_PWM YES
	
;;  PortA, bit 3 has channel 4 mapped to it
  #DEFINE PIN5_CH 4
  #DEFINE PIN5_SINK NO
  #DEFINE PIN5_PWM YES

;;  PortA, bit 4 has channel 5 mapped to it
  #DEFINE PIN6_CH 5
  #DEFINE PIN6_SINK NO
  #DEFINE PIN6_PWM YES

;;  PortA, bit 5 has channel 6 mapped to it
  #DEFINE PIN7_CH 6
  #DEFINE PIN7_SINK NO
  #DEFINE PIN7_PWM YES

;;  PortA, bit 7 has channel 11 mapped to it
  #DEFINE PIN14_CH 11
  #DEFINE PIN14_SINK NO
  #DEFINE PIN14_PWM YES

;;  PortA, bit 6 has channel 10 mapped to it
  #DEFINE PIN13_CH 10
  #DEFINE PIN13_SINK NO
  #DEFINE PIN13_PWM YES
;; ---------------------------- PORT B mapping -------------------------------

;;  PortB, bit 0 has channel 21 mapped to it
  #DEFINE PIN33_CH 21
  #DEFINE PIN33_SINK NO
  #DEFINE PIN33_PWM YES

;;  PortB, bit 1 has channel 22 mapped to it
  #DEFINE PIN34_CH 22
  #DEFINE PIN34_SINK NO
  #DEFINE PIN34_PWM YES

;;  PortB, bit 2 has channel 23 mapped to it
  #DEFINE PIN35_CH 23
  #DEFINE PIN35_SINK NO
  #DEFINE PIN35_PWM YES

;;  PortB, bit 3 has channel 24 mapped to it
  #DEFINE PIN36_CH 24
  #DEFINE PIN36_SINK NO
  #DEFINE PIN36_PWM YES

;;  PortB, bit 4 has channel 17 mapped to it
  #DEFINE PIN37_CH 17
  #DEFINE PIN37_SINK NO
  #DEFINE PIN37_PWM YES

;;  PortB, bit 5 has channel 18 mapped to it
  #DEFINE PIN38_CH 18
  #DEFINE PIN38_SINK NO
  #DEFINE PIN38_PWM YES

;;  PortB, bit 6 has channel 19 mapped to it
  #DEFINE PIN39_CH 19
  #DEFINE PIN39_SINK NO
  #DEFINE PIN39_PWM YES

;;  PortB, bit 7 has channel 20 mapped to it
  #DEFINE PIN40_CH 20
  #DEFINE PIN40_SINK NO
  #DEFINE PIN40_PWM YES

;; ---------------------------- PORT C mapping -------------------------------

;;  PortC, bit 0 has channel 12 mapped to it
  #DEFINE PIN15_CH 12
  #DEFINE PIN15_SINK NO
  #DEFINE PIN15_PWM YES

;;  PortC, bit 1 has channel 13 mapped to it
  #DEFINE PIN16_CH 13
  #DEFINE PIN16_SINK NO
  #DEFINE PIN16_PWM YES

;;  PortC, bit 2 has channel 14 mapped to it
  #DEFINE PIN17_CH 14
  #DEFINE PIN17_SINK NO
  #DEFINE PIN17_PWM YES

;;  PortC, bit 3 has channel 15 mapped to it
  #DEFINE PIN18_CH 15
  #DEFINE PIN18_SINK NO
  #DEFINE PIN18_PWM YES

;;  PortC, bit 4 has channel 31 mapped to it
  #DEFINE PIN23_CH 31
  #DEFINE PIN23_SINK NO
  #DEFINE PIN23_PWM YES

;;  PortC, bit 5 has channel 32 mapped to it
  #DEFINE PIN24_CH 32
  #DEFINE PIN24_SINK NO
  #DEFINE PIN24_PWM YES

;;  PortC, bits 6 and 7 are used for serial (UART) I/O
  #DEFINE PIN25_SINK NO  ;;TX UART
  #DEFINE PIN26_SINK NO  ;;RX UART

;; ---------------------------- PORT D mapping -------------------------------

;;  PortD, bit 0 has channel 16 mapped to it
  #DEFINE PIN19_CH 16
  #DEFINE PIN19_SINK NO
  #DEFINE PIN19_PWM YES
			
;;  PortD, bit 3 has channel 30 mapped to it
  #DEFINE PIN22_CH 30
  #DEFINE PIN22_SINK NO
  #DEFINE PIN22_PWM YES

;;  PortD, bit 2 has channel 29 mapped to it
  #DEFINE PIN21_CH 29
  #DEFINE PIN21_SINK NO
  #DEFINE PIN21_PWM YES

;;  PortD, bit 1 has LED driver mapped to it
  #DEFINE PIN20_SINK NO
  #DEFINE PIN20_PWM YES
  #DEFINE LED2_TRIS TRISD,1
  #DEFINE LED2_anode_sel portd_image,1
  			
;;  PortD, bit 4 has channel 25 mapped to it
  #DEFINE PIN27_CH 25
  #DEFINE PIN27_SINK NO
  #DEFINE PIN27_PWM YES
  
;;  PortD, bit 5 has channel 26 mapped to it
  #DEFINE PIN28_CH 26
  #DEFINE PIN28_SINK NO
  #DEFINE PIN28_PWM YES

;;  PortD, bit 6 has channel 27 mapped to it
  #DEFINE PIN29_CH 27
  #DEFINE PIN29_SINK NO
  #DEFINE PIN29_PWM YES
  
;;  PortD, bit 7 has channel 28 mapped to it
  #DEFINE PIN30_CH 28
  #DEFINE PIN30_SINK NO
  #DEFINE PIN30_PWM YES

;; ---------------------------- PORT E mapping -------------------------------

;;  PortE, bit 0 has channel 7 mapped to it
  #DEFINE PIN8_CH 7
  #DEFINE PIN8_SINK NO
  #DEFINE PIN8_PWM YES
  
;;  PortE, bit 1 has channel 8 mapped to it
  #DEFINE PIN9_CH 8
  #DEFINE PIN9_SINK NO
  #DEFINE PIN9_PWM YES

;;  PortE, bit 2 has channel 9 mapped to it
  #DEFINE PIN10_CH 9
  #DEFINE PIN10_SINK NO
  #DEFINE PIN10_PWM YES
